ProxyTInitOtpBody class

Constructors

ProxyTInitOtpBody({required String otpType, required String contact})
const
ProxyTInitOtpBody.fromJson(Map<String, dynamic> json)
factory

Properties

contact → String
Email or phone number to send the OTP code to
final
hashCode → int
The hash code for this object.
no setterinherited
otpType → String
Enum to specify whether to send OTP via SMS or email
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited