ProxyTInitOtpV2Response class

Constructors

ProxyTInitOtpV2Response({required String otpId, required String otpEncryptionTargetBundle})
const
ProxyTInitOtpV2Response.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
otpEncryptionTargetBundle String
Signed bundle containing a target encryption key to use when submitting OTP codes.
final
otpId String
Unique identifier for an OTP flow.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited