ProxyTOtpLoginV2Body class

Constructors

ProxyTOtpLoginV2Body({required String verificationToken, required String publicKey, required v1ClientSignature clientSignature, bool? invalidateExisting, String? organizationId})
const
ProxyTOtpLoginV2Body.fromJson(Map<String, dynamic> json)
factory

Properties

clientSignature v1ClientSignature
Signature proving authorization for this login. The signature is over the verification token ID and the new session public key.
final
hashCode int
The hash code for this object.
no setterinherited
invalidateExisting bool?
Invalidate all other previously generated Login sessions
final
organizationId String?
Unique identifier for a given Organization. If provided, this organization id will be used directly. If omitted, uses the verification token to look up the verified sub-organization based on the contact and verification type.
final
publicKey String
Client-side public key generated by the user, used as the session public key upon successful login.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationToken String
Session containing a unique id, expiry, verification type, contact. Verification status of a user is updated when the token is consumed (in OTP_LOGIN requests)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited