ProxyTVerifyOtpV2Body class

Constructors

ProxyTVerifyOtpV2Body({required String otpId, required String encryptedOtpBundle})
const
ProxyTVerifyOtpV2Body.fromJson(Map<String, dynamic> json)
factory

Properties

encryptedOtpBundle String
Encrypted bundle containing the OTP code and a client-generated public key. Turnkey's secure enclaves will decrypt this bundle, verify the OTP code, and issue a new Verification Token. Encrypted using the target encryption key provided in the INIT_OTP activity result.
final
hashCode int
The hash code for this object.
no setterinherited
otpId String
ID representing the result of an init OTP activity.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited