hostContainerEncryptedPullSecret property
Optional encrypted pull secret to authorize Turnkey to pull the host container image. If your image is public, leave this empty.
Implementation
final String? hostContainerEncryptedPullSecret;
Optional encrypted pull secret to authorize Turnkey to pull the host container image. If your image is public, leave this empty.
final String? hostContainerEncryptedPullSecret;