pivotContainerEncryptedPullSecret property
Optional encrypted pull secret to authorize Turnkey to pull the pivot container image. If your image is public, leave this empty.
Implementation
final String? pivotContainerEncryptedPullSecret;
Optional encrypted pull secret to authorize Turnkey to pull the pivot container image. If your image is public, leave this empty.
final String? pivotContainerEncryptedPullSecret;