TDeletePoliciesBody class

Constructors

TDeletePoliciesBody({String? timestampMs, String? organizationId, required List<String> policyIds})
const
TDeletePoliciesBody.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
organizationId → String?
final
policyIds → List<String>
List of unique identifiers for policies within an organization
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampMs → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited