TGetWalletAddressBalancesBody class
Constructors
- TGetWalletAddressBalancesBody({String? organizationId, required String address, required String caip2})
-
const
-
TGetWalletAddressBalancesBody.fromJson(Map<
String, dynamic> json) -
factory
Properties
- address → String
-
Address corresponding to a wallet account. Private key addresses are not supported.
final
- caip2 → String
-
CAIP-2 chain ID (e.g., 'eip155:1' for Ethereum mainnet or 'solana:5eykt4UsFv8P8NJdTREpY1vzqKqZKvdp' for Solana mainnet). Human-readable Solana aliases ('solana:mainnet', 'solana:devnet') are also accepted and normalized to canonical CAIP-2 values.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- organizationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited