externaldatav1Credential class

Constructors

externaldatav1Credential({required String publicKey, required v1CredentialType type})
const
externaldatav1Credential.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
publicKey → String
The public component of a cryptographic key pair used to sign messages and transactions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → v1CredentialType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited