immutableactivityv1Address class

Constructors

immutableactivityv1Address({v1AddressFormat? format, String? address})
const
immutableactivityv1Address.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
final
format → v1AddressFormat?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited