v1AppStatus class

Constructors

v1AppStatus({required String appId, required List<v1DeploymentStatus> deployments, required String targetedDeploymentId})
const
v1AppStatus.fromJson(Map<String, dynamic> json)
factory

Properties

appId String
Unique identifier for this TVC App
final
deployments List<v1DeploymentStatus>
List of deployment statuses for this app
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetedDeploymentId String
The deployment ID currently serving traffic for this app
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited