v1AssetBalance class

Constructors

v1AssetBalance({String? caip19, String? symbol, String? balance, num? decimals, v1AssetBalanceDisplay? display, String? name})
const
v1AssetBalance.fromJson(Map<String, dynamic> json)
factory

Properties

balance String?
The balance in atomic units
final
caip19 String?
The caip-19 asset identifier
final
decimals num?
The number of decimals this asset uses
final
display v1AssetBalanceDisplay?
Normalized balance values for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise. Use the balance field instead.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The asset name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String?
The asset symbol
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited