display property
Normalized balance values for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise. Use the balance field instead.
Implementation
final v1AssetBalanceDisplay? display;
Normalized balance values for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise. Use the balance field instead.
final v1AssetBalanceDisplay? display;