v1AssetBalanceDisplay class

Constructors

v1AssetBalanceDisplay({String? usd, String? crypto})
const
v1AssetBalanceDisplay.fromJson(Map<String, dynamic> json)
factory

Properties

crypto String?
Normalized crypto value for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usd String?
USD value for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited