crypto property
Normalized crypto value for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise.
Implementation
final String? crypto;
Normalized crypto value for display purposes only. Do not do any arithmetic or calculations with these, as the results could be imprecise.
final String? crypto;