v1Attestation class

Constructors

v1Attestation({required String credentialId, required String clientDataJson, required String attestationObject, required List<v1AuthenticatorTransport> transports})
const
v1Attestation.fromJson(Map<String, dynamic> json)
factory

Properties

attestationObject → String
A base64 url encoded payload containing authenticator data and any attestation the webauthn provider chooses.
final
clientDataJson → String
A base64 url encoded payload containing metadata about the signing context and the challenge.
final
credentialId → String
The cbor encoded then base64 url encoded id of the credential.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transports → List<v1AuthenticatorTransport>
The type of authenticator transports.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited