v1CreateOauth2CredentialIntent class

Constructors

v1CreateOauth2CredentialIntent({required v1Oauth2Provider provider, required String clientId, required String encryptedClientSecret})
const
v1CreateOauth2CredentialIntent.fromJson(Map<String, dynamic> json)
factory

Properties

clientId → String
The Client ID issued by the OAuth 2.0 provider
final
encryptedClientSecret → String
The client secret issued by the OAuth 2.0 provider encrypted to the TLS Fetcher quorum key
final
hashCode → int
The hash code for this object.
no setterinherited
provider → v1Oauth2Provider
The OAuth 2.0 provider
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited