v1CreateTvcDeploymentIntent class

Constructors

v1CreateTvcDeploymentIntent({required String appId, required String qosVersion, required String pivotContainerImageUrl, required String pivotPath, required List<String> pivotArgs, required String expectedPivotDigest, num? nonce, String? pivotContainerEncryptedPullSecret, bool? debugMode, required v1TvcHealthCheckType healthCheckType, required num healthCheckPort, required num publicIngressPort})
const
v1CreateTvcDeploymentIntent.fromJson(Map<String, dynamic> json)
factory

Properties

appId String
The unique identifier of the to-be-deployed TVC application
final
debugMode bool?
Optional flag to indicate whether to deploy the TVC app in debug mode, which includes additional logging and debugging tools. Default is false.
final
expectedPivotDigest String
Digest of the pivot binary in the pivot container. This value will be inserted in the QOS manifest to ensure application integrity.
final
hashCode int
The hash code for this object.
no setterinherited
healthCheckPort num
Port to use for health checks.
final
healthCheckType v1TvcHealthCheckType
Health check type (TVC_HEALTH_CHECK_TYPE_HTTP or TVC_HEALTH_CHECK_TYPE_GRPC). HTTP health checks are made with a GET request on /health, and gRPC health checks follow the standard gRPC health checking protocol.
final
nonce num?
Optional nonce to ensure uniqueness of the deployment manifest. If not provided, it defaults to the current Unix timestamp in seconds.
final
pivotArgs List<String>
Arguments to pass to the pivot binary at startup. Encoded as a list of strings, for example "--foo", "bar"
final
pivotContainerEncryptedPullSecret String?
Optional encrypted pull secret to authorize Turnkey to pull the pivot container image. If your image is public, leave this empty.
final
pivotContainerImageUrl String
URL of the container containing the pivot binary
final
pivotPath String
Location of the binary in the pivot container
final
publicIngressPort num
Port to use for public ingress.
final
qosVersion String
The QuorumOS version to use to deploy this application
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited