debugMode property

bool? debugMode
final

Optional flag to indicate whether to deploy the TVC app in debug mode, which includes additional logging and debugging tools. Default is false.

Implementation

final bool? debugMode;