v1CreateWebhookEndpointIntent class
Constructors
-
v1CreateWebhookEndpointIntent({required String url, required String name, List<
v1WebhookSubscriptionParams> ? subscriptions}) -
const
-
v1CreateWebhookEndpointIntent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Human-readable name for this webhook endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
v1WebhookSubscriptionParams> ? -
Event subscriptions to create for this endpoint.
final
- url → String
-
The destination URL for webhook delivery.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited