v1DeleteAuthenticatorsResult class

Constructors

v1DeleteAuthenticatorsResult({required List<String> authenticatorIds})
const
v1DeleteAuthenticatorsResult.fromJson(Map<String, dynamic> json)
factory

Properties

authenticatorIds → List<String>
Unique identifier for a given Authenticator.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited