v1DeleteSubOrganizationIntent class

Constructors

v1DeleteSubOrganizationIntent({bool? deleteWithoutExport})
const
v1DeleteSubOrganizationIntent.fromJson(Map<String, dynamic> json)
factory

Properties

deleteWithoutExport → bool?
Sub-organization deletion, by default, requires associated wallets and private keys to be exported for security reasons. Set this boolean to true to force sub-organization deletion even if some wallets or private keys within it have not been exported yet. Default: false.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited