v1DeleteWebhookEndpointResult class
Constructors
- v1DeleteWebhookEndpointResult({required String endpointId})
-
const
-
v1DeleteWebhookEndpointResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endpointId → String
-
Unique identifier of the deleted webhook endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited