v1EthFailureDetails class
Constructors
-
v1EthFailureDetails({List<
v1RevertChainEntry> ? revertChain}) -
const
-
v1EthFailureDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
revertChain
→ List<
v1RevertChainEntry> ? -
Ethereum revert chain, ordered from outermost to innermost.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited