otpEncryptionTargetBundle property
Signed bundle containing a target encryption key to use when submitting OTP codes.
Implementation
final String otpEncryptionTargetBundle;
Signed bundle containing a target encryption key to use when submitting OTP codes.
final String otpEncryptionTargetBundle;