v1Oauth2Credential class

Constructors

v1Oauth2Credential({required String oauth2CredentialId, required String organizationId, required v1Oauth2Provider provider, required String clientId, required String encryptedClientSecret, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
const
v1Oauth2Credential.fromJson(Map<String, dynamic> json)
factory

Properties

clientId → String
The client id for a given OAuth 2.0 Credential.
final
createdAt → externaldatav1Timestamp
final
encryptedClientSecret → String
The encrypted client secret for a given OAuth 2.0 Credential encrypted to the TLS Fetcher quorum key.
final
hashCode → int
The hash code for this object.
no setterinherited
oauth2CredentialId → String
Unique identifier for a given OAuth 2.0 Credential.
final
organizationId → String
Unique identifier for an Organization.
final
provider → v1Oauth2Provider
The provider for a given OAuth 2.0 Credential.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
updatedAt → externaldatav1Timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited