v1OauthProviderParamsV2 class

Constructors

v1OauthProviderParamsV2.fromJson(Map<String, dynamic> json)
factory
v1OauthProviderParamsV2.oidcClaims({required String providerName, required v1OidcClaims oidcClaims})
const
v1OauthProviderParamsV2.oidcToken({required String providerName, required String oidcToken})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
oidcClaims → v1OidcClaims?
OIDC claims (iss, sub, aud) to uniquely identify the user
final
oidcToken → String?
Base64 encoded OIDC token
final
providerName → String
Human-readable name to identify a Provider.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited