v1OidcClaims class

Constructors

v1OidcClaims({required String iss, required String sub, required String aud})
const
v1OidcClaims.fromJson(Map<String, dynamic> json)
factory

Properties

aud String
The audience from the OIDC token (aud claim)
final
hashCode int
The hash code for this object.
no setterinherited
iss String
The issuer identifier from the OIDC token (iss claim)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sub String
The subject identifier from the OIDC token (sub claim)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited