v1OtpLoginIntentV2 class

Constructors

v1OtpLoginIntentV2({required String verificationToken, required String publicKey, required v1ClientSignature clientSignature, String? expirationSeconds, bool? invalidateExisting})
const
v1OtpLoginIntentV2.fromJson(Map<String, dynamic> json)
factory

Properties

clientSignature v1ClientSignature
Required signature proving authorization for this login. The signature is over the verification token ID and the public key. Required for secure OTP login process.
final
expirationSeconds String?
Expiration window (in seconds) indicating how long the Session is valid for. If not provided, a default of 15 minutes will be used.
final
hashCode int
The hash code for this object.
no setterinherited
invalidateExisting bool?
Invalidate all other previously generated Login sessions
final
publicKey String
Client-side public key generated by the user, used as the session public key upon successful login
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationToken String
Signed Verification Token containing a unique id, expiry, verification type, contact
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited