publicKey property
Client-side public key generated by the user, used as the session public key upon successful login
Implementation
final String publicKey;
Client-side public key generated by the user, used as the session public key upon successful login
final String publicKey;