v1Pagination class

Constructors

v1Pagination({String? limit, String? before, String? after})
const
v1Pagination.fromJson(Map<String, dynamic> json)
factory

Properties

after → String?
A pagination cursor. This is an object ID that enables you to fetch all objects after this ID.
final
before → String?
A pagination cursor. This is an object ID that enables you to fetch all objects before this ID.
final
hashCode → int
The hash code for this object.
no setterinherited
limit → String?
A limit of the number of object to be returned, between 1 and 100. Defaults to 10.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited