v1PublicKeyCredentialWithAttestation class

Constructors

v1PublicKeyCredentialWithAttestation({required String id, required String type, required String rawId, String? authenticatorAttachment, required v1AuthenticatorAttestationResponse response, required v1SimpleClientExtensionResults clientExtensionResults})
const
v1PublicKeyCredentialWithAttestation.fromJson(Map<String, dynamic> json)
factory

Properties

authenticatorAttachment → String?
final
clientExtensionResults → v1SimpleClientExtensionResults
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
rawId → String
final
response → v1AuthenticatorAttestationResponse
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited