v1RevertChainEntry class

Constructors

v1RevertChainEntry({String? address, String? errorType, String? displayMessage, v1UnknownRevertError? unknown, v1NativeRevertError? native, v1CustomRevertError? custom})
const
v1RevertChainEntry.fromJson(Map<String, dynamic> json)
factory

Properties

address → String?
The contract address where the revert occurred.
final
custom → v1CustomRevertError?
Details for custom contract errors.
final
displayMessage → String?
Human-readable message describing this revert.
final
errorType → String?
Type of error: 'unknown', 'native', or 'custom'.
final
hashCode → int
The hash code for this object.
no setterinherited
native → v1NativeRevertError?
Details for native Solidity errors (Error, Panic, execution reverted).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → v1UnknownRevertError?
Details for unknown error types.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited