v1SolanaConfig class

Constructors

v1SolanaConfig({bool? rentPrefundEnabled})
const
v1SolanaConfig.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
rentPrefundEnabled bool?
Whether Solana rent prefunding is enabled for the organization. When omitted, the existing rent-prefund state is left unchanged.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited