v1StampLoginIntent class

Constructors

v1StampLoginIntent({required String publicKey, String? expirationSeconds, bool? invalidateExisting})
const
v1StampLoginIntent.fromJson(Map<String, dynamic> json)
factory

Properties

expirationSeconds → String?
Expiration window (in seconds) indicating how long the Session is valid for. If not provided, a default of 15 minutes will be used.
final
hashCode → int
The hash code for this object.
no setterinherited
invalidateExisting → bool?
Invalidate all other previously generated Login API keys
final
publicKey → String
Client-side public key generated by the user, which will be conditionally added to org data based on the passkey stamp associated with this request
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited