v1TvcDeployment class

Constructors

v1TvcDeployment({required String id, required String organizationId, required String appId, required v1TvcOperatorSet manifestSet, required v1TvcOperatorSet shareSet, required v1TvcManifest manifest, required List<v1TvcOperatorApproval> manifestApprovals, required String qosVersion, required v1TvcContainerSpec pivotContainer, required v1TvcContainerSpec hostContainer, required v1TvcDeploymentStage stage, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
const
v1TvcDeployment.fromJson(Map<String, dynamic> json)
factory

Properties

appId String
Unique Identifier of the TVC App for this deployment
final
createdAt externaldatav1Timestamp
final
hashCode int
The hash code for this object.
no setterinherited
hostContainer v1TvcContainerSpec
The pivot container spec for this deployment
final
id String
Unique Identifier for this TVC Deployment.
final
manifest v1TvcManifest
The manifest used for this deployment
final
manifestApprovals List<v1TvcOperatorApproval>
List of operator approvals for this manifest
final
manifestSet v1TvcOperatorSet
Set of TVC operators who can approve this deployment
final
organizationId String
Unique Identifier of the Organization for this TVC Deployment
final
pivotContainer v1TvcContainerSpec
The pivot container spec for this deployment
final
qosVersion String
QOS Version used for this deployment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareSet v1TvcOperatorSet
Set of TVC operators who have a share of the Quorum Key
final
stage v1TvcDeploymentStage
Current stage for this deployment
final
updatedAt externaldatav1Timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited