v1TvcOperator class

Constructors

v1TvcOperator({required String id, required String name, required String publicKey, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
const
v1TvcOperator.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt externaldatav1Timestamp
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique Identifier for this TVC Operator.
final
name String
Name of this TVC Operator.
final
publicKey String
Public key for this TVC Operator.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
updatedAt externaldatav1Timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited