v1TvcOperatorSet class

Constructors

v1TvcOperatorSet({required String id, required String name, required String organizationId, required List<v1TvcOperator> operators, required num threshold, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
const
v1TvcOperatorSet.fromJson(Map<String, dynamic> json)
factory

Properties

createdAt externaldatav1Timestamp
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique Identifier for this TVC Operator Set.
final
name String
Name of this TVC Operator Set.
final
operators List<v1TvcOperator>
List of TVC Operators in this set
final
organizationId String
Unique Identifier of the Organization for this TVC Operator Set
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threshold num
Threshold number of operators required for quorum.
final
updatedAt externaldatav1Timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited