socialLinkingClientIds property

List<String>? socialLinkingClientIds
final

Whitelisted OAuth client IDs for social account linking. When a user authenticates via a social provider with an email matching an existing account, the accounts will be linked if the client ID is in this list and the issuer is considered a trusted provider.

Implementation

final List<String>? socialLinkingClientIds;