v1UpdateWebhookEndpointResult class

Constructors

v1UpdateWebhookEndpointResult({required String endpointId, required v1WebhookEndpointData webhookEndpoint})
const
v1UpdateWebhookEndpointResult.fromJson(Map<String, dynamic> json)
factory

Properties

endpointId String
Unique identifier of the updated webhook endpoint.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webhookEndpoint v1WebhookEndpointData
The updated webhook endpoint data.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited