v1UpsertGasUsageConfigIntent class
Properties
-
enabled
→ bool?
-
Whether gas sponsorship is enabled for the organization.
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
orgWindowLimitUsd
→ String
-
Gas sponsorship USD limit for the billing organization window.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
solanaConfig
→ v1SolanaConfig?
-
Optional Solana sponsorship settings. If omitted, the existing Solana sponsorship state is left unchanged.
final
-
subOrgWindowLimitUsd
→ String
-
Gas sponsorship USD limit for sub-organizations under the billing organization.
final
-
windowDurationMinutes
→ String
-
Rolling sponsorship window duration, expressed in minutes.
final