encryptedOtpBundle property

String encryptedOtpBundle
final

Encrypted bundle containing the OTP code and a client-generated public key. Turnkey's secure enclaves will decrypt this bundle, verify the OTP code, and issue a new Verification Token. Encrypted using the target encryption key provided in the INIT_OTP activity result.

Implementation

final String encryptedOtpBundle;