proxyOtpLoginV2 method
Produce a SignedRequest from ProxyTOtpLoginBody by using the client's stamp function.
See also: OtpLogin.
Login using an existing OTP Verification Token and a client-side signature. The signature's public key must match the public key contained within the OTP Verification Token.
Sign the provided ProxyTOtpLoginV2Body with the client's stamp function and submit the request (POST /v1/otp_login_v2).
See also: stampOtpLoginV2.
Implementation
/// Login using an existing OTP Verification Token and a client-side signature. The signature's public key must match the public key contained within the OTP Verification Token.
///
/// Sign the provided `ProxyTOtpLoginV2Body` with the client's `stamp` function and submit the request (POST /v1/otp_login_v2).
///
/// See also: `stampOtpLoginV2`.
Future<ProxyTOtpLoginV2Response> proxyOtpLoginV2({
required ProxyTOtpLoginV2Body input,
}) async {
return await authProxyRequest<ProxyTOtpLoginV2Body,
ProxyTOtpLoginV2Response>("/v1/otp_login_v2", input,
(json) => ProxyTOtpLoginV2Response.fromJson(json));
}