v1AssetMetadata class
Constructors
- v1AssetMetadata({String? caip19, String? symbol, num? decimals, String? logoUrl, String? name})
-
const
-
v1AssetMetadata.fromJson(Map<
String, dynamic> json) -
factory
Properties
- caip19 → String?
-
The caip-19 asset identifier
final
- decimals → num?
-
The number of decimals this asset uses
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logoUrl → String?
-
The url of the asset logo
final
- name → String?
-
The asset name
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String?
-
The asset symbol
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited