v1DeploymentStatus class
Constructors
- v1DeploymentStatus({required String deploymentId, required num readyReplicas, required num desiredReplicas, required externaldatav1Timestamp lastUpdatedTime})
-
const
-
v1DeploymentStatus.fromJson(Map<
String, dynamic> json) -
factory
Properties
- deploymentId → String
-
Unique identifier for this deployment (corresponds to k8s deployment label)
final
- desiredReplicas → num
-
Desired number of replicas
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lastUpdatedTime → externaldatav1Timestamp
-
Last time this deployment was updated
final
- readyReplicas → num
-
Number of ready replicas
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited