v1OtpLoginIntentV2 class
Properties
clientSignature
→ v1ClientSignature
Required signature proving authorization for this login. The signature is over the verification token ID and the public key. Required for secure OTP login process.
final
expirationSeconds
→ String ?
Expiration window (in seconds) indicating how long the Session is valid for. If not provided, a default of 15 minutes will be used.
final
hashCode
→ int
The hash code for this object.
no setter inherited
invalidateExisting
→ bool ?
Invalidate all other previously generated Login sessions
final
publicKey
→ String
Client-side public key generated by the user, used as the session public key upon successful login
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
verificationToken
→ String
Signed Verification Token containing a unique id, expiry, verification type, contact
final