v1SolanaFailureDetails class

Constructors

v1SolanaFailureDetails({String? source, num? rpcCode, String? rpcMessage, String? transactionErrorJson, List<String>? logs, String? unitsConsumed, String? innerInstructionsJson})
const
v1SolanaFailureDetails.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
innerInstructionsJson String?
The raw Solana inner instructions payload serialized as JSON, if available.
final
logs List<String>?
Program logs returned by Solana simulation or preflight, if available.
final
rpcCode num?
The Solana JSON-RPC error code, if available.
final
rpcMessage String?
The Solana JSON-RPC error message, if available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
Where the Solana failure occurred, such as simulation or preflight.
final
transactionErrorJson String?
The raw Solana transaction error object serialized as JSON, if available.
final
unitsConsumed String?
Compute units consumed during simulation or preflight, if available.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited