v1TvcManifest class
Constructors
- v1TvcManifest({required String id, required String manifest, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
-
const
-
v1TvcManifest.fromJson(Map<
String, dynamic> json) -
factory
Properties
- createdAt → externaldatav1Timestamp
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique Identifier for this TVC Manifest.
final
- manifest → String
-
The manifest content (raw UTF-8 JSON bytes)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → externaldatav1Timestamp
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited