v1TvcOperatorApproval class
Constructors
- v1TvcOperatorApproval({required String id, required String manifestId, required v1TvcOperator operator, required String approval, required externaldatav1Timestamp createdAt, required externaldatav1Timestamp updatedAt})
-
const
-
v1TvcOperatorApproval.fromJson(Map<
String, dynamic> json) -
factory
Properties
- approval → String
-
Signature of the operator over the deployment manifest
final
- createdAt → externaldatav1Timestamp
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique ID for this approval
final
- manifestId → String
-
Unique Identifier of the TVC Manifest being approved
final
- operator → v1TvcOperator
-
The TVC Operator who made this approval
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatedAt → externaldatav1Timestamp
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited