v1UpdateWebhookEndpointIntent class
Constructors
- v1UpdateWebhookEndpointIntent({required String endpointId, String? url, String? name, bool? isActive})
-
const
-
v1UpdateWebhookEndpointIntent.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endpointId → String
-
Unique identifier of the webhook endpoint to update.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool?
-
Whether this webhook endpoint is active.
final
- name → String?
-
Updated human-readable name for this webhook endpoint.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
Updated destination URL for webhook delivery.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited