v1UpsertGasUsageConfigIntent class

Constructors

v1UpsertGasUsageConfigIntent({required String orgWindowLimitUsd, required String subOrgWindowLimitUsd, required String windowDurationMinutes, bool? enabled})
const
v1UpsertGasUsageConfigIntent.fromJson(Map<String, dynamic> json)
factory

Properties

enabled bool?
Whether gas sponsorship is enabled for the organization.
final
hashCode int
The hash code for this object.
no setterinherited
orgWindowLimitUsd String
Gas sponsorship USD limit for the billing organization window.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subOrgWindowLimitUsd String
Gas sponsorship USD limit for sub-organizations under the billing organization.
final
windowDurationMinutes String
Rolling sponsorship window duration, expressed in minutes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited