v1VerifyOtpIntentV2 class
Properties
-
encryptedOtpBundle
→ String
-
Encrypted bundle containing the OTP code and a client-generated public key. Turnkey's secure enclaves will decrypt this bundle, verify the OTP code, and issue a new Verification Token. Encrypted using the target encryption key provided in the INIT_OTP activity result.
final
-
expirationSeconds
→ String?
-
Expiration window (in seconds) indicating how long the verification token is valid for. If not provided, a default of 1 hour will be used. Maximum value is 86400 seconds (24 hours)
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
otpId
→ String
-
UUID representing an OTP flow. A new UUID is created for each init OTP activity.
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited