v1WebhookEndpointData class
Constructors
-
v1WebhookEndpointData({required String endpointId, required String organizationId, required String url, required String name, required bool isActive, List<
v1WebhookSubscriptionParams> ? subscriptions}) -
const
-
v1WebhookEndpointData.fromJson(Map<
String, dynamic> json) -
factory
Properties
- endpointId → String
-
Unique identifier of the webhook endpoint.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether this webhook endpoint is active.
final
- name → String
-
Human-readable name for this webhook endpoint.
final
- organizationId → String
-
Unique identifier for a given Organization.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
subscriptions
→ List<
v1WebhookSubscriptionParams> ? -
Current subscriptions attached to this endpoint.
final
- url → String
-
The destination URL for webhook delivery.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited