getNonces method
Get nonce values for an address on a given network. Can fetch the standard on-chain nonce and/or the gas station nonce used for sponsored transactions.
Sign the provided TGetNoncesBody with the client's stamp function and submit the request (POST /public/v1/query/get_nonces).
See also: stampGetNonces.
Implementation
Future<TGetNoncesResponse> getNonces({
required TGetNoncesBody input,
}) async {
return await request<TGetNoncesBody, TGetNoncesResponse>(
"/public/v1/query/get_nonces",
input,
(json) => TGetNoncesResponse.fromJson(json));
}